@@ -124,10 +124,21 @@ def theme_settings(theme, site):
             'colors_uks': site.secondary_color_uks,
             'bg_color': site.secondary_bg_color,
         },
+        constants.THEME_LIGHT_INVERSE: {
+            'colors_uks': site.secondary_inverse_color_uks,
+            'bg_color': site.secondary_inverse_bg_color,
+        }
     }
     return themes[theme] if theme in themes else None
 
 
+@register.filter
+def theme_reverse(theme):
+    if '-inverse' in theme:
+        return theme.replace('-inverse', '')
+    return theme + '-inverse'
+
+
 @register.filter
 def debug(item):
     import pdb
